@@ -1,14 +1,15 @@
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Dict, Union
+from secrets import token_hex
+from typing import Any, Dict
 
 from pydantic import BaseSettings, DirectoryPath
 
 from learninghouse import versions
 from learninghouse.api.errors import (LearningHouseException,
                                       LearningHouseValidationError)
-from learninghouse.core import LearningHouseEnum
 from learninghouse.core.logging import LoggingLevelEnum
+from learninghouse.models.base import EnumModel
 
 LICENSE_URL = 'https://github.com/LearningHouseService/learninghouse-core/blob/master/LICENSE'
 
@@ -29,8 +30,12 @@ class ServiceSettings(BaseSettings):
 
     logging_level: LoggingLevelEnum = LoggingLevelEnum.INFO
 
+    jwt_secret: str = token_hex(16)
+    jwt_expire_minutes: int = 30
+
     class Config:  # pylint: disable=too-few-public-methods
         validate_assignment = True
+        env_file = '.env'
         env_prefix = 'learninghouse_'
 
     @property
@@ -57,7 +62,8 @@ class ServiceSettings(BaseSettings):
     def uvicorn_kwargs(self) -> Dict[str, Any]:
         kwargs = {
             'host': self.host,
-            'port': self.port
+            'port': self.port,
+            'headers': [('server', f'LearningHouse Service {versions.service}')]
         }
 
         if self.reload:
@@ -71,7 +77,7 @@ class ServiceSettings(BaseSettings):
 
     @property
     def base_url(self) -> str:
-        if self.host == '0.0.0.0' or self.host == '127.0.0.1':
+        if self.host in ('0.0.0.0', '127.0.0.1'):
             base_url = f'http://localhost:{self.port}'
         else:
             base_url = f'http://{self.host}:{self.port}'
@@ -79,7 +85,7 @@ class ServiceSettings(BaseSettings):
         return base_url
 
     @property
-    def documentation_url(self) -> Union[str, None]:
+    def documentation_url(self) -> str | None:
         documentation_url = None
 
         if self.docs_url is not None:
@@ -87,22 +93,16 @@ class ServiceSettings(BaseSettings):
 
         return documentation_url
 
-    @property
-    def oauth2_redirect_url(self) -> Union[str, None]:
-        redirect_url = None
-
-        if self.docs_url is not None and self.is_oauth_activated:
-            redirect_url = self.docs_url + '/oauth2-redirect'
-
-        return redirect_url
-
     @property
     def openapi_url(self) -> str:
         return self.base_url + self.openapi_file
 
     @property
-    def is_oauth_activated(self) -> bool:
-        return False
+    def jwt_payload_claims(self) -> Dict[str, str]:
+        return {
+            'audience': 'LearningHouseAPI',
+            'issuer': 'LearningHouse Service'
+        }
 
 
 class DevelopmentSettings(ServiceSettings):
@@ -110,19 +110,21 @@ class DevelopmentSettings(ServiceSettings):
     debug: bool = True
     reload: bool = True
     title: str = 'learningHouse Service - Development'
+    api_key_required: bool = False
 
     class Config(ServiceSettings.Config):  # pylint: disable=too-few-public-methods
         env_file = '.env'
         env_prefix = 'learninghouse_'
 
 
-class ServiceEnvironment(LearningHouseEnum):
+class ServiceEnvironment(str, EnumModel):
     PROD = 'production', ServiceSettings
     DEV = 'development', DevelopmentSettings
 
     def __init__(self,
                  description: str,
                  settings_class: ServiceSettings):
+        # pylint: disable=super-init-not-called
         self._description: str = description
         self._settings_class: ServiceSettings = settings_class
 
