@@ -1,9 +1,8 @@
 from __future__ import annotations
 
 from datetime import datetime
-import json
 from os import path, stat
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
 import joblib
 import pandas as pd
@@ -11,18 +10,17 @@ from sklearn.feature_selection import SelectFromModel
 from sklearn.metrics import accuracy_score
 
 from learninghouse import versions
-from learninghouse.api.errors import LearningHouseException
 from learninghouse.api.errors.brain import (BrainNoConfiguration,
-                                            BrainNotActual,
-                                            BrainNotEnoughData,
+                                            BrainNotActual, BrainNotEnoughData,
                                             BrainNotTrained)
 from learninghouse.core.logging import logger
 from learninghouse.models import LearningHouseVersions
-from learninghouse.models.brain import (BrainEstimatorConfiguration,
-                                        BrainEstimatorType, BrainInfo,
-                                        BrainPredictionResult)
+from learninghouse.models.brain import BrainInfo, BrainPredictionResult
+from learninghouse.models.configuration import (
+    BrainConfiguration,
+    BrainEstimatorType, BrainFileType, sanitize_configuration_filename,
+)
 from learninghouse.models.preprocessing import DatasetConfiguration
-from learninghouse.services import sanitize_configuration_filename
 from learninghouse.services.preprocessing import DatasetPreprocessing
 
 if TYPE_CHECKING:
@@ -30,66 +28,29 @@ if TYPE_CHECKING:
 
 
 class Brain():
-    CONFIG_FILE = 'config.json'
-    TRAINED_FILE = 'trained.pkl'
-    INFO_FILE = 'info.json'
-
     def __init__(self, name: str):
         self.name: str = name
-
-        json_config = self._load_initial_config(name)
-
-        self.estimatorcfg: BrainEstimatorConfiguration = BrainEstimatorConfiguration(
-            **self._required_param(json_config, 'estimator'))
+        self.configuration: BrainConfiguration = BrainConfiguration.from_json_file(
+            name)
 
         self.dataset: DatasetConfiguration = DatasetConfiguration(
-            dependent=self._required_param(json_config, 'dependent'),
-            testsize=self._required_param(json_config, 'test_size'),
-            dependent_encode=self._optional_param(
-                json_config, 'dependent_encode', False),
+            self.configuration)
 
-        )
+        self._estimator: Optional[RandomForestClassifier |
+                                  RandomForestRegressor] = None
 
-        self._estimator: Optional[Union[RandomForestClassifier,
-                                        RandomForestRegressor]] = None
         self.score: Optional[float] = 0.0
 
         self.versions: LearningHouseVersions = versions
 
         self.trained_at: Optional[datetime] = None
 
-    @classmethod
-    def _load_initial_config(cls, name: str) -> Dict[str, Any]:
-        filename = sanitize_configuration_filename(name, cls.CONFIG_FILE)
-
-        with open(filename, 'r', encoding='utf-8') as config_file:
-            return json.load(config_file)
-
-    @classmethod
-    def _required_param(cls, json_config: Dict[str, Any], param_key: str) -> Any:
-        param_value = cls._optional_param(json_config, param_key)
-
-        if param_value is None:
-            raise RuntimeError(
-                f'Missing required configuration parameter {param_key}')
-
-        return param_value
-
-    @staticmethod
-    def _optional_param(json_config: Dict[str, Any], param_key: str, default=None) -> Any | None:
-        param_value = default
-
-        if param_key in json_config:
-            param_value = json_config[param_key]
-
-        return param_value
-
     def estimator(self) -> RandomForestClassifier | RandomForestRegressor:
         if self._estimator is None:
-            self._estimator = self.estimatorcfg.typed.estimator_class(
-                n_estimators=self.estimatorcfg.estimators,
-                max_depth=self.estimatorcfg.max_depth,
-                random_state=self.estimatorcfg.random_state
+            self._estimator = self.configuration.estimator.typed.estimator_class(
+                n_estimators=self.configuration.estimator.estimators,
+                max_depth=self.configuration.estimator.max_depth,
+                random_state=self.configuration.estimator.random_state
             )
 
         return self._estimator
@@ -98,10 +59,9 @@ class Brain():
     def info(self) -> BrainInfo:
         info = BrainInfo(
             name=self.name,
-            estimator_config=self.estimatorcfg,
+            configuration=self.configuration,
             features=self.dataset.features,
-            dependent=self.dataset.dependent,
-            dependent_encode=self.dataset.dependent_encode,
+            training_data_size=self.dataset.data_size,
             score=self.score,
             trained_at=self.trained_at,
             versions=self.versions
@@ -110,15 +70,16 @@ class Brain():
         return info
 
     @classmethod
-    def load_trained(cls, name: str) -> Brain:
+    def load_trained(cls, name: str, check_versions: Optional[bool] = True) -> Brain:
         try:
             filename = sanitize_configuration_filename(
-                name, cls.TRAINED_FILE)
+                name, BrainFileType.TRAINED_FILE)
             brain_config = joblib.load(filename)
             if brain_config.versions != versions:
                 logger.warning(
                     f'Trained brain {name} is not actual. Versions: {brain_config.versions}')
-                raise BrainNotActual(name, brain_config.versions)
+                if check_versions:
+                    raise BrainNotActual(name, brain_config.versions)
 
             return brain_config
         except FileNotFoundError as exc:
@@ -126,28 +87,30 @@ class Brain():
 
     def store_trained(self,
                       columns: List[str],
+                      training_data_size: int,
                       score: float) -> None:
         self.dataset.columns = columns
+        self.dataset.data_size = training_data_size
         self.score = score
         self.trained_at = datetime.now()
 
         filename = sanitize_configuration_filename(
-            self.name, self.TRAINED_FILE)
+            self.name, BrainFileType.TRAINED_FILE)
 
         joblib.dump(self, filename)
 
-        filename = sanitize_configuration_filename(self.name, self.INFO_FILE)
+        filename = sanitize_configuration_filename(
+            self.name, BrainFileType.INFO_FILE)
         with open(filename, 'w', encoding='utf-8') as infofile:
             infofile.write(self.info.json(indent=4))
 
 
 class BrainTraining():
-    TRAINING_DATA_FILE = 'training_data.csv'
 
     @classmethod
     def request(cls, name: str, request_data: Optional[Dict[str, Any]] = None) -> BrainInfo:
         filename = sanitize_configuration_filename(
-            name, cls.TRAINING_DATA_FILE)
+            name, BrainFileType.TRAINING_DATA_FILE)
 
         if request_data is None:
             if path.exists(filename):
@@ -191,20 +154,18 @@ class BrainTraining():
 
             estimator.fit(x_train, y_train)
 
-            if BrainEstimatorType.CLASSIFIER == brain.estimatorcfg.typed:
+            if BrainEstimatorType.CLASSIFIER == brain.configuration.estimator.typed:
                 y_pred = estimator.predict(x_test)
                 score = accuracy_score(y_test, y_pred)
             else:
                 score = estimator.score(x_test, y_test)
 
-            brain.store_trained(x_train.columns.tolist(), score)
+            brain.store_trained(x_train.columns.tolist(),
+                                len(data.index), score)
 
             return brain.info
         except FileNotFoundError as exc:
             raise BrainNoConfiguration(name) from exc
-        except Exception as exc:  # pylint: disable=broad-except
-            logger.exception(exc)
-            raise LearningHouseException() from exc
 
 
 class BrainPrediction():
@@ -213,7 +174,7 @@ class BrainPrediction():
     @classmethod
     def prediction(cls, name: str, request_data: Dict[str, Any]):
         try:
-            brain = cls._load_brain(name)
+            brain = cls.load_brain(name)
             request_data = DatasetPreprocessing.add_time_information(
                 request_data)
 
@@ -223,8 +184,8 @@ class BrainPrediction():
 
             prediction = brain.estimator().predict(prepared_data)
 
-            if (brain.dataset.dependent_encode
-                    and brain.estimatorcfg.typed == BrainEstimatorType.CLASSIFIER):
+            if (brain.configuration.dependent_encode
+                    and brain.configuration.estimator.typed == BrainEstimatorType.CLASSIFIER):
                 prediction = brain.dataset.dependent_encoder.inverse_transform(
                     prediction)
                 prediction = list(map(bool, prediction))
@@ -238,14 +199,11 @@ class BrainPrediction():
             )
         except FileNotFoundError as exc:
             raise BrainNotTrained(name) from exc
-        except Exception as exc:  # pylint: disable=broad-except
-            logger.exception(exc)
-            raise LearningHouseException() from exc
 
     @classmethod
-    def _load_brain(cls, name: str) -> Brain:
+    def load_brain(cls, name: str) -> Brain:
         filename = sanitize_configuration_filename(
-            name, Brain.TRAINED_FILE)
+            name, BrainFileType.TRAINED_FILE)
         stamp = stat(filename).st_mtime
 
         if not(name in cls.brains and cls.brains[name]['stamp'] == stamp):
